#[non_exhaustive]pub enum ImmutableWriteError {
DifferentObject {
object_key: String,
},
Transport {
object_key: String,
source: ObjectStoreError,
},
}Expand description
Failure to establish that an immutable key contains the requested bytes.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
DifferentObject
The key names bytes other than the immutable payload supplied here.
Transport
The storage boundary failed before byte identity could be established.
Fields

source: ObjectStoreErrorFinal storage failure after retry and read-back reconciliation.
Implementations
Sourceimpl ImmutableWriteError
impl ImmutableWriteError
Sourcepub fn object_key(&self) -> &str
pub fn object_key(&self) -> &str
Returns the immutable object key whose byte identity was not established.